@@ -4,4 +4,4 @@ from django.utils.translation import pgettext_lazy
 
 class LikeConfig(AppConfig):
     name = 'likes'
-    verbose_name = pgettext_lazy("like", "Likes")
+    verbose_name = pgettext_lazy("ok:likes", "Likes")
